@@ -4,10 +4,12 @@
 /* Author: Rainer Doemer			first version: 03/26/01 */
 /************************************************************************/
 
-/* last update: 06/01/01 */
+/* last update: 08/01/01 */
 
 /* modifications: (most recent first)
  *
+ * 08/01/01 RD	added missing ThreadDelete() call in DeleteChildren()
+ *		(uncritical for posix threads, but needed for quick threads)
  * 06/01/01 RD	bug fix for bug showing up on linux
  * 05/25/01 RD	removed code not needed for the SCRC
  * 05/16/01 RD	resolved name space competition with user by moving more
@@ -639,6 +641,7 @@ while(Child)
    { Next = Child->NextSibling;
      assert(Child != CurrentThread);	/* must not commit suicide */
      assert(Child->NumChildren == 0);	/* must not have any grand children */
+     Child->ThreadDelete();
      delete Child;
      Child = Next;
     } /* elihw */
